<?php

/**
 * @file
 * Notification functions for the 'Expire Questions' module
 * 
 * @author Chip Cleary
 * 
 */

/* 
 * The file provides notification functions
 *    1. Notify question authors when their questions are able to be extended
 *    2. Notify question authors when their questions have expired
 */

/*
 * Add settings to the notification form
 */ 
function _expire_questions_notify_settings(&$form) {

  $form['expire_questions']['notifications_settings'] = array(
    '#type' => 'fieldset',
    '#description' => t('Settings for notification emails.'),
    '#title' => t('Notification Email Settings'),
  );

  $form['expire_questions']['notifications_settings']['question_can_be_extended'] = array(
    '#type' => 'fieldset',
    '#description' => t('Notify question author that a question can now be extended.'),
    '#title' => t('Extension Notification'),
  );

  $form['expire_questions']['notifications_settings']['question_can_be_extended']['expire_questions_notify_question_can_be_extended_p'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Notify authors when they can extend expiration of their questions?'),
    '#default_value' => variable_get('expire_questions_notify_question_can_be_extended_p', FALSE),
  );

  $form['expire_questions']['notifications_settings']['question_can_be_extended']['expire_questions_question_can_be_extended_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject line'),
    '#default_value' => variable_get('expire_questions_question_can_be_extended_notification_subject', ''),
    '#description' => t('Dynamic variables available: !question_user_name, !question_title, !question_url, !question_expiration, and !site'),
    '#required' => TRUE
  );

    $form['expire_questions']['notifications_settings']['question_can_be_extended']['expire_questions_question_can_be_extended_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => variable_get('expire_questions_question_can_be_extended_notification_body', ''),
    '#description' => t('Dynamic variables available: !question_user_name, !question_title, !question_url, !question_expiration, and !site'),
    '#required' => TRUE
  );

  $form['expire_questions']['notifications_settings']['question_expired'] = array(
    '#type' => 'fieldset',
    '#description' => t('Notify question author that a question has expired.'),
    '#title' => t('Expiration Notification'),
  );

  $form['expire_questions']['notifications_settings']['question_expired']['expire_questions_notify_question_expiration_p'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Notify author after a question expires?'),
    '#default_value' => variable_get('expire_questions_notify_question_expiration_p', FALSE),
  );
  
  $form['expire_questions']['notifications_settings']['question_expired']['expire_questions_question_expired_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject line'),
    '#default_value' => variable_get('expire_questions_question_expired_notification_subject', ''),
    '#description' => t('Dynamic variables available: !question_user_name, !question_title, !question_url, !question_expiration, !site, and !site_url'),
    '#required' => TRUE
  );

    $form['expire_questions']['notifications_settings']['question_expired']['expire_questions_question_expired_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => variable_get('expire_questions_question_expired_notification_body', ''),
    '#description' => t('Dynamic variables available: !question_user_name, !question_title, !question_url, !question_expiration, !site, and !site_url'),
    '#required' => TRUE
  );
  
}

function _expire_questions_notify_question_expired($question) {
  watchdog('expire_answers', 'question expired: question %nid', array('%nid' => $question->nid));
  if (variable_get('expire_questions_notify_question_expiration_p', NULL)) {
    expire_questions_notify('expire_questions', $question, 'question_expired');
  }
}

function _expire_questions_notify_question_can_be_extended($question) {
  watchdog('expire_answers', 'question can be extended: question %nid', array('%nid' => $question->nid));
  if (variable_get('expire_questions_notify_question_can_be_extended_p', NULL)) {
  expire_questions_notify('expire_questions', $question, 'question_can_be_extended');
  }
}

function expire_questions_notify($module, $question, $notification) {
  $params = array(
    '!question_expiration' => date(DATE_RFC822, answers_field_get_value($question, 'field_question_expiration')),
  );
  answers_notify($module, $question, $notification, $params);
}

/**
 * Implements hook_mail().
 */
function expire_questions_mail($key, &$message, $params) {
  switch ($key) {
    case 'question_expired':
      $subject_template = variable_get('expire_questions_question_expired_notification_subject', '');
      $body_template = variable_get('expire_questions_question_expired_notification_body', '');
      break;

    case 'question_can_be_extended':
      $subject_template = variable_get('expire_questions_question_can_be_extended_notification_subject', '');
      $body_template = variable_get('expire_questions_question_can_be_extended_notification_body', '');
      break;
  }

  answers_mail_helper($key, $message, $params, $subject_template, $body_template);	
}